﻿using System;
using System.Windows;
using test.WebApp;
using Microsoft.AspNetCore.Components.WebView.Wpf;
using Microsoft.Extensions.DependencyInjection;

namespace test.App;

/// <summary>
///     Interaction logic for MainWindow.xaml
/// </summary>
public partial class MainWindow : Window
{
    public MainWindow()
    {
        InitializeComponent();
        this.MaxHeight = SystemParameters.MaximizedPrimaryScreenHeight - 9;

        var webView = new BlazorWebView
        {
            HostPage = @$"{Environment.CurrentDirectory}\wwwroot\index.html"
        };
        var services = new ServiceCollection();
        services.AddWpfBlazorWebView();
        webView.Services = services.BuildServiceProvider();
        webView.RootComponents.Add(new RootComponent
        {
            ComponentType = typeof(Root),
            Selector = "#app"
        });

        WebViewContainer.Child = webView;

        AppDomain.CurrentDomain.UnhandledException += (sender, error) =>
        {
            MessageBox.Show(error.ExceptionObject.ToString(), "Unhandled Exception", MessageBoxButton.OK,
                MessageBoxImage.Error);
        };
    }

    private void StackPanel_MouseLeftButtonDown(object sender, System.Windows.Input.MouseButtonEventArgs e)
    {
        DragMove();
    }

    private void btn_Minimize_Click(object sender, RoutedEventArgs e)
    {
        WindowState = WindowState.Minimized;
    }

    private void btn_Maximize_Click(object sender, RoutedEventArgs e)
    {
        if (WindowState == WindowState.Maximized)
            WindowState = WindowState.Normal;
        else WindowState = WindowState.Maximized;
    }

    private void btn_Close_Click(object sender, RoutedEventArgs e)
    {
        Application.Current.Shutdown();
    }
}